@@ -7,7 +7,7 @@ BEGIN {
 }
 
 
-our $VERSION =  '0.01_01';
+our $VERSION =  '0.01_02';
 
 =head1 NAME
 
@@ -597,7 +597,7 @@ BEGIN { # Initialization goes here
 
 
 	# We put code here to execute it only once
-	my $usercontext =  <<'	CODE' =~ s#^\t\t##rgm;
+	(my $usercontext =  <<'	CODE') =~ s#^\t\t##gm;
 		BEGIN{
 			( $^H, ${^WARNING_BITS}, my $hr ) =  @DB::context[1..3];
 			%^H =  %$hr   if $hr;
@@ -1260,7 +1260,7 @@ sub push_frame {
 sub sub {
 	$DB::_sub =  $DB::sub;
 	print $DB::OUT "DB::sub  l:$DB::ddlvl b:$DB::inDB:$DB::inSUB e:$DB::ext_call s:$DB::single t:$DB::trace  --  "
-		.sub{ "$DB::sub <-- @{[ map{ s#.*?([^/]+)$#$1#r } (caller 0)[1,2] ]}" }->()
+		.sub{ "$DB::sub <-- @{[ map{ s#.*?([^/]+)$#$1# } (caller 0)[1,2] ]}" }->()
 		."\n"
 		if $DB::options{ ddd } && $DB::sub ne 'DB::can_break';
 
@@ -1330,31 +1330,34 @@ sub sub {
 # The perl may not "...fall back to &DB::sub (args)."
 # http://perldoc.perl.org/perldebguts.html#Debugger-Internals
 sub lsub : lvalue {
+	my $x;
 	if( $ext_call ) {
 		BEGIN{ 'strict'->unimport( 'refs' )   if $options{ s } };
-		return &$DB::sub
+		$x =  &$DB::sub
+	}
+	else {
+		# manual localization
+		Hook::Scope::POST( \&sub_returns );
+		push @{ DB::state( 'stack' ) }, {
+			single      =>  DB::state( 'single' ),
+			sub         =>  $DB::sub,
+			goto_frames =>  DB::state( 'goto_frames' ),
+		};
+
+		DB::state( 'goto_frames', [] );
+
+
+		# HERE TOO client's code 'caller' return wrong info
+		trace_subs( 'L' );
+
+		DB::state( 'single', 0 )   if DB::state( 'single' ) & 2;
+		{
+			BEGIN{ 'strict'->unimport( 'refs' )   if $options{ s } }
+			$x =  &$DB::sub;
+		}
 	}
 
-
-	# manual localization
-	Hook::Scope::POST( \&sub_returns );
-	push @{ DB::state( 'stack' ) }, {
-		single      =>  DB::state( 'single' ),
-		sub         =>  $DB::sub,
-		goto_frames =>  DB::state( 'goto_frames' ),
-	};
-
-	DB::state( 'goto_frames', [] );
-
-
-	# HERE TOO client's code 'caller' return wrong info
-	trace_subs( 'L' );
-
-	DB::state( 'single', 0 )   if DB::state( 'single' ) & 2;
-	{
-		BEGIN{ 'strict'->unimport( 'refs' )   if $options{ s } }
-		return &$DB::sub;
-	}
+	$x;
 };
 
 
