@@ -101,7 +101,7 @@ sub _list {
 		print $DB::OUT $file eq $run_file  &&  $line == $run_line ? '>>' : '  ';
 
 		print $DB::OUT DB::can_break( $file, $line ) ? 'x' : ' ';
-		print $DB::OUT "$line: " . ($source->[ $line ] =~ s/\t/    /rg ); #/
+		print $DB::OUT "$line: " . ((my $tmp=$source->[ $line ]) =~ s/\t/    /g ); #/
 	}
 }
 
@@ -344,7 +344,7 @@ $DB::commands =  {
 		$curr_file   =  DB::state( 'file' );
 		$line_cursor =  DB::state( 'line' );
 
-		print $DB::OUT "$curr_file:$line_cursor    " .(DB::source()->[ $line_cursor ] =~ s/^(\s+)//r); #/
+		print $DB::OUT "$curr_file:$line_cursor    " .((my $tmp=DB::source()->[ $line_cursor ]) =~ s/^(\s+)//); #/
 
 		1;
 	},
